diff --git a/Raylib-cs/interop/Raylib.cs b/Raylib-cs/interop/Raylib.cs
index ca1df8c..31d8e83 100644
--- a/Raylib-cs/interop/Raylib.cs
+++ b/Raylib-cs/interop/Raylib.cs
@@ -1809,9 +1809,9 @@ public static unsafe partial class Raylib
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
public static extern void UnloadTexture(Texture2D texture);
/// Check if a render texture is ready
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
- public static extern CBool IsRenderTextureReady(RenderTexture2D target);
+ public static extern CBool IsRenderTextureValid(RenderTexture2D target);
/// Unload render texture from GPU memory (VRAM)
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
@@ -1809,9 +1809,9 @@ public static unsafe partial class Raylib
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
public static extern void UnloadTexture(Texture2D texture);
- /// Check if a render texture is ready
+ /// Check if a render texture is valid (loaded in GPU)
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]